const { GraphQLError, Kind } = require('graphql');
const isEmail = require('validator/lib/isEmail');
const isURL = require('validator/lib/isURL');

//console.log(Kind)

const emailTypeObject = {
  name: 'Email',
  description: 'The Email scalar type represents E-Mail addresses compliant to RFC 822.',
  serialize: isEmail, parseValue: isEmail,
  parseLiteral(ast) {
    const error = 'Query error: Not a valid Email address'
    if (ast.kind !== Kind.STRING) {
      throw new GraphQLError('Query error: Can only parse strings got a: ' + ast.kind, [ast]);
    }
    if(!isEmail(ast.value)) {
      throw new GraphQLError(error, [ast]);
    }
    return ast.value;
  }
}

const urlTypeObject = {
  name: 'Url',
  description: 'The URL scalar type represents URL addresses.',
  serialize: isURL, parseValue: isURL,
  parseLiteral(ast) {
    const error = 'Query error: Not a valid Url'
    if (ast.kind !== Kind.STRING) {
      throw new GraphQLError('Query error: Can only parse strings got a: ' + ast.kind, [ast]);
    }
    if(!isURL(ast.value)) {
      throw new GraphQLError(error, [ast]);
    }
    return ast.value;
  }
}

module.exports = {
  emailTypeObject,
  urlTypeObject
}
